from_map16

Function from_map16 

pub fn from_map16<I: AsRef<Path>, O: AsRef<Path>>(
    input_file: I,
    output_folder: O,
) -> Result<()>
Converts from a binary map16 file to a folder tree of human-readable text files.

Examples

use human_readable_map16::from_map16;
 
from_map16("input.map16", "map16_folder");

Panics

This function does not panic.

Errors

Returns an error if any step of the conversion fails. This could be for many reasons, the input file not existing, invalid formatting of the input file, problems writing the output, etc.

Error::Conversion should contain a fairly descriptive message if it is returned. Other errors should rarely occur.